@@ -392,7 +392,26 @@ class FPLAnalytics:
                         'assist_diff90',
                         'bps90']
 
-        players = self.findPlayer(player1 + ' ' + player2)
+        try:
+            player1Det = [p.strip() for p in player1.split("+")]
+            player2Det = [p.strip() for p in player2.split("+")]
+            
+            if len(player1Det) == 1 and len(player2Det) == 1:
+                players = self.findPlayer(player1 + ',' + player2)
+            else:
+                players = pd.DataFrame()
+                for player in [player1Det, player2Det]:
+                    temp = self.findPlayer(",".join(player))
+                    if temp.shape[0] == len(player):
+                        temp['group'] = "+".join(list(temp['web_name'].values))
+                        players = pd.concat([players, temp])
+                players = players[['web_name', 'group'] + features]
+                players = players.groupby(by = ["group"]).sum()
+                players.reset_index(inplace = True)
+                players.rename(columns = {"group" : "web_name"}, inplace=True)
+            
+        except:
+            players = self.findPlayer(player1 + ',' + player2)
 
         if players.shape[0] == 2:
             N = len(features)
